@@ -876,9 +876,6 @@ SV* dbd_db_FETCH_attrib(SV* dbh, imp_dbh_t* imp_dbh, SV* keysv) {
 	    char* info = mysql_info(imp_dbh->svsock);
 	    return info ? sv_2mortal(newSVpv(info, strlen(info))) : &sv_undef;
 	}
-	if (strEQ(key, "insertid")) {
-	    return sv_2mortal(newSViv((IV) mysql_insert_id(imp_dbh->svsock)));
-	}
 	break;
 #endif
       case 'p':
@@ -1190,7 +1187,7 @@ int dbd_st_execute(SV* sth, imp_sth_t* imp_sth) {
 	!= -2) {
 	if (!imp_sth->cda) {
 #if defined(DBD_MYSQL)
-	    imp_sth->insertid = (int) mysql_insert_id(imp_dbh->svsock);
+	    imp_sth->insertid = mysql_insert_id(imp_dbh->svsock);
 #endif
 	} else {
 	    /** Store the result in the current statement handle */
